@@ -215,7 +215,6 @@ const (
 	SiteCaSecret             string = "skupper-site-ca"
 	ConsoleServerSecret      string = "skupper-console-certs"
 	ConsoleUsersSecret       string = "skupper-console-users"
-	ConsoleSessionSecret     string = "skupper-console-session"
 	PrometheusServerSecret   string = "skupper-prometheus-certs"
 	OauthRouterConsoleSecret string = "skupper-router-console-certs"
 	ServiceCaSecret          string = "skupper-service-ca"
@@ -258,6 +257,7 @@ const (
 	TypeTokenRequestQualifier   string = BaseQualifier + "/type=connection-token-request"
 	TokenGeneratedBy            string = BaseQualifier + "/generated-by"
 	SiteVersion                 string = BaseQualifier + "/site-version"
+	SiteId                      string = BaseQualifier + "/site-id"
 	TokenCost                   string = BaseQualifier + "/cost"
 	TokenTemplate               string = BaseQualifier + "/token-template"
 	UpdatedAnnotation           string = InternalQualifier + "/updated"
@@ -320,33 +320,39 @@ type Platform string
 
 const (
 	PlatformKubernetes Platform = "kubernetes"
-	PlatformPodman              = "podman"
+	PlatformPodman     Platform = "podman"
+	PlatformDocker     Platform = "docker"
+	PlatformLinux      Platform = "linux"
 )
 
 func (p Platform) IsKubernetes() bool {
 	return p == "" || p == PlatformKubernetes
 }
 
+func (p Platform) IsContainerEngine() bool {
+	return p == PlatformDocker || p == PlatformPodman
+}
+
 type ConsoleAuthMode string
 
 const (
 	ConsoleAuthModeOpenshift ConsoleAuthMode = "openshift"
-	ConsoleAuthModeInternal                  = "internal"
-	ConsoleAuthModeUnsecured                 = "unsecured"
+	ConsoleAuthModeInternal  ConsoleAuthMode = "internal"
+	ConsoleAuthModeUnsecured ConsoleAuthMode = "unsecured"
 )
 
 const (
 	ClaimRedemptionPort      int32  = 8081
 	ClaimRedemptionPortName  string = "claims"
-	ClaimRedemptionRouteName string = "claims"
+	ClaimRedemptionRouteName string = "skupper-claims"
 )
 
 type PrometheusAuthMode string
 
 const (
 	PrometheusAuthModeTls       PrometheusAuthMode = "tls"
-	PrometheusAuthModeBasic                        = "basic"
-	PrometheusAuthModeUnsecured                    = "unsecured"
+	PrometheusAuthModeBasic     PrometheusAuthMode = "basic"
+	PrometheusAuthModeUnsecured PrometheusAuthMode = "unsecured"
 )
 
 // Prometheus server constants (note: use console auth mode)
@@ -533,7 +539,7 @@ type ConnectorRole string
 
 const (
 	ConnectorRoleInterRouter ConnectorRole = "inter-router"
-	ConnectorRoleEdge                      = "edge"
+	ConnectorRoleEdge        ConnectorRole = "edge"
 )
 
 const (
@@ -566,6 +572,7 @@ type Credential struct {
 	Data        map[string][]byte
 	Simple      bool `default:"false"`
 	Labels      map[string]string
+	Expiration  time.Duration
 }
 
 type CertAuthority struct {
@@ -832,7 +839,7 @@ func (a ByServiceInterfaceAddress) Len() int {
 }
 
 func (a ByServiceInterfaceAddress) Less(i, j int) bool {
-	return a[i].Address > a[i].Address
+	return a[i].Address < a[j].Address
 }
 
 func (a ByServiceInterfaceAddress) Swap(i, j int) {
@@ -842,13 +849,3 @@ func (a ByServiceInterfaceAddress) Swap(i, j int) {
 func QualifiedServiceName(name string, namespace string) string {
 	return name + "." + namespace + ".svc.cluster.local"
 }
-
-const (
-	TokenRoleClaim string = "claim"
-	TokenRoleCert  string = "cert"
-)
-
-const (
-	TokenCreatorLocal  string = "local"
-	TokenCreatorRemote string = "remote"
-)
