@@ -548,8 +548,18 @@ func TestCmdConnectorCreate_InputToOptions(t *testing.T) {
 
 	testTable := []test{
 		{
-			name:                   "test1",
-			flags:                  common.CommandConnectorCreateFlags{"backend", "", "app=backend", "secret", "tcp", true, "", 20 * time.Second, "ready"},
+			name: "test1",
+			flags: common.CommandConnectorCreateFlags{
+				RoutingKey:          "backend",
+				Host:                "",
+				Selector:            "app=backend",
+				TlsCredentials:      "secret",
+				ConnectorType:       "tcp",
+				IncludeNotReadyPods: true,
+				Workload:            "",
+				Timeout:             20 * time.Second,
+				Wait:                "ready",
+			},
 			expectedTlsCredentials: "secret",
 			expectedHost:           "",
 			expectedRoutingKey:     "backend",
@@ -559,8 +569,18 @@ func TestCmdConnectorCreate_InputToOptions(t *testing.T) {
 			expectedStatus:         "ready",
 		},
 		{
-			name:                   "test2",
-			flags:                  common.CommandConnectorCreateFlags{"backend", "backend", "", "secret", "tcp", true, "", 20 * time.Second, "configured"},
+			name: "test2",
+			flags: common.CommandConnectorCreateFlags{
+				RoutingKey:          "backend",
+				Host:                "backend",
+				Selector:            "",
+				TlsCredentials:      "secret",
+				ConnectorType:       "tcp",
+				IncludeNotReadyPods: true,
+				Workload:            "",
+				Timeout:             20 * time.Second,
+				Wait:                "configured",
+			},
 			expectedTlsCredentials: "secret",
 			expectedHost:           "backend",
 			expectedRoutingKey:     "backend",
@@ -570,8 +590,18 @@ func TestCmdConnectorCreate_InputToOptions(t *testing.T) {
 			expectedStatus:         "configured",
 		},
 		{
-			name:                   "test3",
-			flags:                  common.CommandConnectorCreateFlags{"", "", "", "secret", "tcp", false, "", 30 * time.Second, "none"},
+			name: "test3",
+			flags: common.CommandConnectorCreateFlags{
+				RoutingKey:          "",
+				Host:                "",
+				Selector:            "",
+				TlsCredentials:      "secret",
+				ConnectorType:       "tcp",
+				IncludeNotReadyPods: false,
+				Workload:            "",
+				Timeout:             30 * time.Second,
+				Wait:                "none",
+			},
 			expectedTlsCredentials: "secret",
 			expectedHost:           "",
 			expectedRoutingKey:     "test3",
